@@ -33,6 +33,7 @@ from google.cloud.secretmanager_v1.types import resources
 from google.cloud.secretmanager_v1.types import service
 from google.iam.v1 import iam_policy_pb2 as iam_policy  # type: ignore
 from google.iam.v1 import policy_pb2 as policy  # type: ignore
+from google.protobuf import duration_pb2 as duration  # type: ignore
 from google.protobuf import field_mask_pb2 as field_mask  # type: ignore
 from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
 
@@ -92,6 +93,7 @@ class SecretManagerServiceAsyncClient:
         SecretManagerServiceClient.parse_common_location_path
     )
 
+    from_service_account_info = SecretManagerServiceClient.from_service_account_info
     from_service_account_file = SecretManagerServiceClient.from_service_account_file
     from_service_account_json = from_service_account_file
 
@@ -169,7 +171,7 @@ class SecretManagerServiceAsyncClient:
         r"""Lists [Secrets][google.cloud.secretmanager.v1.Secret].
 
         Args:
-            request (:class:`~.service.ListSecretsRequest`):
+            request (:class:`google.cloud.secretmanager_v1.types.ListSecretsRequest`):
                 The request object. Request message for
                 [SecretManagerService.ListSecrets][google.cloud.secretmanager.v1.SecretManagerService.ListSecrets].
             parent (:class:`str`):
@@ -177,6 +179,7 @@ class SecretManagerServiceAsyncClient:
                 with the
                 [Secrets][google.cloud.secretmanager.v1.Secret], in the
                 format ``projects/*``.
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -188,7 +191,7 @@ class SecretManagerServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.pagers.ListSecretsAsyncPager:
+            google.cloud.secretmanager_v1.services.secret_manager_service.pagers.ListSecretsAsyncPager:
                 Response message for
                 [SecretManagerService.ListSecrets][google.cloud.secretmanager.v1.SecretManagerService.ListSecrets].
 
@@ -256,13 +259,14 @@ class SecretManagerServiceAsyncClient:
         [SecretVersions][google.cloud.secretmanager.v1.SecretVersion].
 
         Args:
-            request (:class:`~.service.CreateSecretRequest`):
+            request (:class:`google.cloud.secretmanager_v1.types.CreateSecretRequest`):
                 The request object. Request message for
                 [SecretManagerService.CreateSecret][google.cloud.secretmanager.v1.SecretManagerService.CreateSecret].
             parent (:class:`str`):
                 Required. The resource name of the project to associate
                 with the [Secret][google.cloud.secretmanager.v1.Secret],
                 in the format ``projects/*``.
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -273,13 +277,15 @@ class SecretManagerServiceAsyncClient:
                 characters and can contain uppercase and lowercase
                 letters, numerals, and the hyphen (``-``) and underscore
                 (``_``) characters.
+
                 This corresponds to the ``secret_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            secret (:class:`~.resources.Secret`):
+            secret (:class:`google.cloud.secretmanager_v1.types.Secret`):
                 Required. A
                 [Secret][google.cloud.secretmanager.v1.Secret] with
                 initial field values.
+
                 This corresponds to the ``secret`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -291,14 +297,14 @@ class SecretManagerServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.resources.Secret:
-                A [Secret][google.cloud.secretmanager.v1.Secret] is a
-                logical secret whose value and versions can be accessed.
+            google.cloud.secretmanager_v1.types.Secret:
+                A [Secret][google.cloud.secretmanager.v1.Secret] is a logical secret whose value and versions can
+                   be accessed.
 
-                A [Secret][google.cloud.secretmanager.v1.Secret] is made
-                up of zero or more
-                [SecretVersions][google.cloud.secretmanager.v1.SecretVersion]
-                that represent the secret data.
+                   A [Secret][google.cloud.secretmanager.v1.Secret] is
+                   made up of zero or more
+                   [SecretVersions][google.cloud.secretmanager.v1.SecretVersion]
+                   that represent the secret data.
 
         """
         # Create or coerce a protobuf request object.
@@ -359,7 +365,7 @@ class SecretManagerServiceAsyncClient:
         [Secret][google.cloud.secretmanager.v1.Secret].
 
         Args:
-            request (:class:`~.service.AddSecretVersionRequest`):
+            request (:class:`google.cloud.secretmanager_v1.types.AddSecretVersionRequest`):
                 The request object. Request message for
                 [SecretManagerService.AddSecretVersion][google.cloud.secretmanager.v1.SecretManagerService.AddSecretVersion].
             parent (:class:`str`):
@@ -368,12 +374,14 @@ class SecretManagerServiceAsyncClient:
                 associate with the
                 [SecretVersion][google.cloud.secretmanager.v1.SecretVersion]
                 in the format ``projects/*/secrets/*``.
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            payload (:class:`~.resources.SecretPayload`):
+            payload (:class:`google.cloud.secretmanager_v1.types.SecretPayload`):
                 Required. The secret payload of the
                 [SecretVersion][google.cloud.secretmanager.v1.SecretVersion].
+
                 This corresponds to the ``payload`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -385,7 +393,7 @@ class SecretManagerServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.resources.SecretVersion:
+            google.cloud.secretmanager_v1.types.SecretVersion:
                 A secret version resource in the
                 Secret Manager API.
 
@@ -443,13 +451,14 @@ class SecretManagerServiceAsyncClient:
         [Secret][google.cloud.secretmanager.v1.Secret].
 
         Args:
-            request (:class:`~.service.GetSecretRequest`):
+            request (:class:`google.cloud.secretmanager_v1.types.GetSecretRequest`):
                 The request object. Request message for
                 [SecretManagerService.GetSecret][google.cloud.secretmanager.v1.SecretManagerService.GetSecret].
             name (:class:`str`):
                 Required. The resource name of the
                 [Secret][google.cloud.secretmanager.v1.Secret], in the
                 format ``projects/*/secrets/*``.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -461,14 +470,14 @@ class SecretManagerServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.resources.Secret:
-                A [Secret][google.cloud.secretmanager.v1.Secret] is a
-                logical secret whose value and versions can be accessed.
+            google.cloud.secretmanager_v1.types.Secret:
+                A [Secret][google.cloud.secretmanager.v1.Secret] is a logical secret whose value and versions can
+                   be accessed.
 
-                A [Secret][google.cloud.secretmanager.v1.Secret] is made
-                up of zero or more
-                [SecretVersions][google.cloud.secretmanager.v1.SecretVersion]
-                that represent the secret data.
+                   A [Secret][google.cloud.secretmanager.v1.Secret] is
+                   made up of zero or more
+                   [SecretVersions][google.cloud.secretmanager.v1.SecretVersion]
+                   that represent the secret data.
 
         """
         # Create or coerce a protobuf request object.
@@ -523,18 +532,20 @@ class SecretManagerServiceAsyncClient:
         [Secret][google.cloud.secretmanager.v1.Secret].
 
         Args:
-            request (:class:`~.service.UpdateSecretRequest`):
+            request (:class:`google.cloud.secretmanager_v1.types.UpdateSecretRequest`):
                 The request object. Request message for
                 [SecretManagerService.UpdateSecret][google.cloud.secretmanager.v1.SecretManagerService.UpdateSecret].
-            secret (:class:`~.resources.Secret`):
+            secret (:class:`google.cloud.secretmanager_v1.types.Secret`):
                 Required. [Secret][google.cloud.secretmanager.v1.Secret]
                 with updated field values.
+
                 This corresponds to the ``secret`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            update_mask (:class:`~.field_mask.FieldMask`):
+            update_mask (:class:`google.protobuf.field_mask_pb2.FieldMask`):
                 Required. Specifies the fields to be
                 updated.
+
                 This corresponds to the ``update_mask`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -546,14 +557,14 @@ class SecretManagerServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.resources.Secret:
-                A [Secret][google.cloud.secretmanager.v1.Secret] is a
-                logical secret whose value and versions can be accessed.
+            google.cloud.secretmanager_v1.types.Secret:
+                A [Secret][google.cloud.secretmanager.v1.Secret] is a logical secret whose value and versions can
+                   be accessed.
 
-                A [Secret][google.cloud.secretmanager.v1.Secret] is made
-                up of zero or more
-                [SecretVersions][google.cloud.secretmanager.v1.SecretVersion]
-                that represent the secret data.
+                   A [Secret][google.cloud.secretmanager.v1.Secret] is
+                   made up of zero or more
+                   [SecretVersions][google.cloud.secretmanager.v1.SecretVersion]
+                   that represent the secret data.
 
         """
         # Create or coerce a protobuf request object.
@@ -610,13 +621,14 @@ class SecretManagerServiceAsyncClient:
         r"""Deletes a [Secret][google.cloud.secretmanager.v1.Secret].
 
         Args:
-            request (:class:`~.service.DeleteSecretRequest`):
+            request (:class:`google.cloud.secretmanager_v1.types.DeleteSecretRequest`):
                 The request object. Request message for
                 [SecretManagerService.DeleteSecret][google.cloud.secretmanager.v1.SecretManagerService.DeleteSecret].
             name (:class:`str`):
                 Required. The resource name of the
                 [Secret][google.cloud.secretmanager.v1.Secret] to delete
                 in the format ``projects/*/secrets/*``.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -678,7 +690,7 @@ class SecretManagerServiceAsyncClient:
         This call does not return secret data.
 
         Args:
-            request (:class:`~.service.ListSecretVersionsRequest`):
+            request (:class:`google.cloud.secretmanager_v1.types.ListSecretVersionsRequest`):
                 The request object. Request message for
                 [SecretManagerService.ListSecretVersions][google.cloud.secretmanager.v1.SecretManagerService.ListSecretVersions].
             parent (:class:`str`):
@@ -687,6 +699,7 @@ class SecretManagerServiceAsyncClient:
                 associated with the
                 [SecretVersions][google.cloud.secretmanager.v1.SecretVersion]
                 to list, in the format ``projects/*/secrets/*``.
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -698,7 +711,7 @@ class SecretManagerServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.pagers.ListSecretVersionsAsyncPager:
+            google.cloud.secretmanager_v1.services.secret_manager_service.pagers.ListSecretVersionsAsyncPager:
                 Response message for
                 [SecretManagerService.ListSecretVersions][google.cloud.secretmanager.v1.SecretManagerService.ListSecretVersions].
 
@@ -767,7 +780,7 @@ class SecretManagerServiceAsyncClient:
         [SecretVersion][google.cloud.secretmanager.v1.SecretVersion].
 
         Args:
-            request (:class:`~.service.GetSecretVersionRequest`):
+            request (:class:`google.cloud.secretmanager_v1.types.GetSecretVersionRequest`):
                 The request object. Request message for
                 [SecretManagerService.GetSecretVersion][google.cloud.secretmanager.v1.SecretManagerService.GetSecretVersion].
             name (:class:`str`):
@@ -777,6 +790,7 @@ class SecretManagerServiceAsyncClient:
                 ``projects/*/secrets/*/versions/latest`` is an alias to
                 the ``latest``
                 [SecretVersion][google.cloud.secretmanager.v1.SecretVersion].
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -788,7 +802,7 @@ class SecretManagerServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.resources.SecretVersion:
+            google.cloud.secretmanager_v1.types.SecretVersion:
                 A secret version resource in the
                 Secret Manager API.
 
@@ -849,13 +863,14 @@ class SecretManagerServiceAsyncClient:
         [SecretVersion][google.cloud.secretmanager.v1.SecretVersion].
 
         Args:
-            request (:class:`~.service.AccessSecretVersionRequest`):
+            request (:class:`google.cloud.secretmanager_v1.types.AccessSecretVersionRequest`):
                 The request object. Request message for
                 [SecretManagerService.AccessSecretVersion][google.cloud.secretmanager.v1.SecretManagerService.AccessSecretVersion].
             name (:class:`str`):
                 Required. The resource name of the
                 [SecretVersion][google.cloud.secretmanager.v1.SecretVersion]
                 in the format ``projects/*/secrets/*/versions/*``.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -867,7 +882,7 @@ class SecretManagerServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.service.AccessSecretVersionResponse:
+            google.cloud.secretmanager_v1.types.AccessSecretVersionResponse:
                 Response message for
                 [SecretManagerService.AccessSecretVersion][google.cloud.secretmanager.v1.SecretManagerService.AccessSecretVersion].
 
@@ -937,7 +952,7 @@ class SecretManagerServiceAsyncClient:
         [DISABLED][google.cloud.secretmanager.v1.SecretVersion.State.DISABLED].
 
         Args:
-            request (:class:`~.service.DisableSecretVersionRequest`):
+            request (:class:`google.cloud.secretmanager_v1.types.DisableSecretVersionRequest`):
                 The request object. Request message for
                 [SecretManagerService.DisableSecretVersion][google.cloud.secretmanager.v1.SecretManagerService.DisableSecretVersion].
             name (:class:`str`):
@@ -945,6 +960,7 @@ class SecretManagerServiceAsyncClient:
                 [SecretVersion][google.cloud.secretmanager.v1.SecretVersion]
                 to disable in the format
                 ``projects/*/secrets/*/versions/*``.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -956,7 +972,7 @@ class SecretManagerServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.resources.SecretVersion:
+            google.cloud.secretmanager_v1.types.SecretVersion:
                 A secret version resource in the
                 Secret Manager API.
 
@@ -1018,7 +1034,7 @@ class SecretManagerServiceAsyncClient:
         [ENABLED][google.cloud.secretmanager.v1.SecretVersion.State.ENABLED].
 
         Args:
-            request (:class:`~.service.EnableSecretVersionRequest`):
+            request (:class:`google.cloud.secretmanager_v1.types.EnableSecretVersionRequest`):
                 The request object. Request message for
                 [SecretManagerService.EnableSecretVersion][google.cloud.secretmanager.v1.SecretManagerService.EnableSecretVersion].
             name (:class:`str`):
@@ -1026,6 +1042,7 @@ class SecretManagerServiceAsyncClient:
                 [SecretVersion][google.cloud.secretmanager.v1.SecretVersion]
                 to enable in the format
                 ``projects/*/secrets/*/versions/*``.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -1037,7 +1054,7 @@ class SecretManagerServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.resources.SecretVersion:
+            google.cloud.secretmanager_v1.types.SecretVersion:
                 A secret version resource in the
                 Secret Manager API.
 
@@ -1100,7 +1117,7 @@ class SecretManagerServiceAsyncClient:
         and irrevocably destroys the secret data.
 
         Args:
-            request (:class:`~.service.DestroySecretVersionRequest`):
+            request (:class:`google.cloud.secretmanager_v1.types.DestroySecretVersionRequest`):
                 The request object. Request message for
                 [SecretManagerService.DestroySecretVersion][google.cloud.secretmanager.v1.SecretManagerService.DestroySecretVersion].
             name (:class:`str`):
@@ -1108,6 +1125,7 @@ class SecretManagerServiceAsyncClient:
                 [SecretVersion][google.cloud.secretmanager.v1.SecretVersion]
                 to destroy in the format
                 ``projects/*/secrets/*/versions/*``.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -1119,7 +1137,7 @@ class SecretManagerServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.resources.SecretVersion:
+            google.cloud.secretmanager_v1.types.SecretVersion:
                 A secret version resource in the
                 Secret Manager API.
 
@@ -1179,7 +1197,7 @@ class SecretManagerServiceAsyncClient:
         [Secret][google.cloud.secretmanager.v1.Secret].
 
         Args:
-            request (:class:`~.iam_policy.SetIamPolicyRequest`):
+            request (:class:`google.iam.v1.iam_policy_pb2.SetIamPolicyRequest`):
                 The request object. Request message for `SetIamPolicy`
                 method.
 
@@ -1190,72 +1208,62 @@ class SecretManagerServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.policy.Policy:
-                Defines an Identity and Access Management (IAM) policy.
-                It is used to specify access control policies for Cloud
-                Platform resources.
+            google.iam.v1.policy_pb2.Policy:
+                Defines an Identity and Access Management (IAM) policy. It is used to
+                   specify access control policies for Cloud Platform
+                   resources.
 
-                A ``Policy`` is a collection of ``bindings``. A
-                ``binding`` binds one or more ``members`` to a single
-                ``role``. Members can be user accounts, service
-                accounts, Google groups, and domains (such as G Suite).
-                A ``role`` is a named list of permissions (defined by
-                IAM or configured by users). A ``binding`` can
-                optionally specify a ``condition``, which is a logic
-                expression that further constrains the role binding
-                based on attributes about the request and/or target
-                resource.
+                   A Policy is a collection of bindings. A binding binds
+                   one or more members to a single role. Members can be
+                   user accounts, service accounts, Google groups, and
+                   domains (such as G Suite). A role is a named list of
+                   permissions (defined by IAM or configured by users).
+                   A binding can optionally specify a condition, which
+                   is a logic expression that further constrains the
+                   role binding based on attributes about the request
+                   and/or target resource.
 
-                **JSON Example**
+                   **JSON Example**
 
-                ::
+                      {
+                         "bindings": [
+                            {
+                               "role":
+                               "roles/resourcemanager.organizationAdmin",
+                               "members": [ "user:mike@example.com",
+                               "group:admins@example.com",
+                               "domain:google.com",
+                               "serviceAccount:my-project-id@appspot.gserviceaccount.com"
+                               ]
 
-                    {
-                      "bindings": [
-                        {
-                          "role": "roles/resourcemanager.organizationAdmin",
-                          "members": [
-                            "user:mike@example.com",
-                            "group:admins@example.com",
-                            "domain:google.com",
-                            "serviceAccount:my-project-id@appspot.gserviceaccount.com"
-                          ]
-                        },
-                        {
-                          "role": "roles/resourcemanager.organizationViewer",
-                          "members": ["user:eve@example.com"],
-                          "condition": {
-                            "title": "expirable access",
-                            "description": "Does not grant access after Sep 2020",
-                            "expression": "request.time <
-                            timestamp('2020-10-01T00:00:00.000Z')",
-                          }
-                        }
-                      ]
-                    }
+                            }, { "role":
+                            "roles/resourcemanager.organizationViewer",
+                            "members": ["user:eve@example.com"],
+                            "condition": { "title": "expirable access",
+                            "description": "Does not grant access after
+                            Sep 2020", "expression": "request.time <
+                            timestamp('2020-10-01T00:00:00.000Z')", } }
 
-                **YAML Example**
+                         ]
 
-                ::
+                      }
 
-                    bindings:
-                    - members:
-                      - user:mike@example.com
-                      - group:admins@example.com
-                      - domain:google.com
-                      - serviceAccount:my-project-id@appspot.gserviceaccount.com
-                      role: roles/resourcemanager.organizationAdmin
-                    - members:
-                      - user:eve@example.com
-                      role: roles/resourcemanager.organizationViewer
-                      condition:
-                        title: expirable access
-                        description: Does not grant access after Sep 2020
-                        expression: request.time < timestamp('2020-10-01T00:00:00.000Z')
+                   **YAML Example**
 
-                For a description of IAM and its features, see the `IAM
-                developer's
-                guide <https://cloud.google.com/iam/docs>`__.
+                      bindings: - members: - user:\ mike@example.com -
+                      group:\ admins@example.com - domain:google.com -
+                      serviceAccount:\ my-project-id@appspot.gserviceaccount.com
+                      role: roles/resourcemanager.organizationAdmin -
+                      members: - user:\ eve@example.com role:
+                      roles/resourcemanager.organizationViewer
+                      condition: title: expirable access description:
+                      Does not grant access after Sep 2020 expression:
+                      request.time <
+                      timestamp('2020-10-01T00:00:00.000Z')
+
+                   For a description of IAM and its features, see the
+                   [IAM developer's
+                   guide](\ https://cloud.google.com/iam/docs).
 
         """
         # Create or coerce a protobuf request object.
@@ -1298,7 +1306,7 @@ class SecretManagerServiceAsyncClient:
         have a policy set.
 
         Args:
-            request (:class:`~.iam_policy.GetIamPolicyRequest`):
+            request (:class:`google.iam.v1.iam_policy_pb2.GetIamPolicyRequest`):
                 The request object. Request message for `GetIamPolicy`
                 method.
 
@@ -1309,72 +1317,62 @@ class SecretManagerServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.policy.Policy:
-                Defines an Identity and Access Management (IAM) policy.
-                It is used to specify access control policies for Cloud
-                Platform resources.
+            google.iam.v1.policy_pb2.Policy:
+                Defines an Identity and Access Management (IAM) policy. It is used to
+                   specify access control policies for Cloud Platform
+                   resources.
 
-                A ``Policy`` is a collection of ``bindings``. A
-                ``binding`` binds one or more ``members`` to a single
-                ``role``. Members can be user accounts, service
-                accounts, Google groups, and domains (such as G Suite).
-                A ``role`` is a named list of permissions (defined by
-                IAM or configured by users). A ``binding`` can
-                optionally specify a ``condition``, which is a logic
-                expression that further constrains the role binding
-                based on attributes about the request and/or target
-                resource.
+                   A Policy is a collection of bindings. A binding binds
+                   one or more members to a single role. Members can be
+                   user accounts, service accounts, Google groups, and
+                   domains (such as G Suite). A role is a named list of
+                   permissions (defined by IAM or configured by users).
+                   A binding can optionally specify a condition, which
+                   is a logic expression that further constrains the
+                   role binding based on attributes about the request
+                   and/or target resource.
 
-                **JSON Example**
+                   **JSON Example**
 
-                ::
+                      {
+                         "bindings": [
+                            {
+                               "role":
+                               "roles/resourcemanager.organizationAdmin",
+                               "members": [ "user:mike@example.com",
+                               "group:admins@example.com",
+                               "domain:google.com",
+                               "serviceAccount:my-project-id@appspot.gserviceaccount.com"
+                               ]
 
-                    {
-                      "bindings": [
-                        {
-                          "role": "roles/resourcemanager.organizationAdmin",
-                          "members": [
-                            "user:mike@example.com",
-                            "group:admins@example.com",
-                            "domain:google.com",
-                            "serviceAccount:my-project-id@appspot.gserviceaccount.com"
-                          ]
-                        },
-                        {
-                          "role": "roles/resourcemanager.organizationViewer",
-                          "members": ["user:eve@example.com"],
-                          "condition": {
-                            "title": "expirable access",
-                            "description": "Does not grant access after Sep 2020",
-                            "expression": "request.time <
-                            timestamp('2020-10-01T00:00:00.000Z')",
-                          }
-                        }
-                      ]
-                    }
+                            }, { "role":
+                            "roles/resourcemanager.organizationViewer",
+                            "members": ["user:eve@example.com"],
+                            "condition": { "title": "expirable access",
+                            "description": "Does not grant access after
+                            Sep 2020", "expression": "request.time <
+                            timestamp('2020-10-01T00:00:00.000Z')", } }
 
-                **YAML Example**
+                         ]
 
-                ::
+                      }
 
-                    bindings:
-                    - members:
-                      - user:mike@example.com
-                      - group:admins@example.com
-                      - domain:google.com
-                      - serviceAccount:my-project-id@appspot.gserviceaccount.com
-                      role: roles/resourcemanager.organizationAdmin
-                    - members:
-                      - user:eve@example.com
-                      role: roles/resourcemanager.organizationViewer
-                      condition:
-                        title: expirable access
-                        description: Does not grant access after Sep 2020
-                        expression: request.time < timestamp('2020-10-01T00:00:00.000Z')
+                   **YAML Example**
 
-                For a description of IAM and its features, see the `IAM
-                developer's
-                guide <https://cloud.google.com/iam/docs>`__.
+                      bindings: - members: - user:\ mike@example.com -
+                      group:\ admins@example.com - domain:google.com -
+                      serviceAccount:\ my-project-id@appspot.gserviceaccount.com
+                      role: roles/resourcemanager.organizationAdmin -
+                      members: - user:\ eve@example.com role:
+                      roles/resourcemanager.organizationViewer
+                      condition: title: expirable access description:
+                      Does not grant access after Sep 2020 expression:
+                      request.time <
+                      timestamp('2020-10-01T00:00:00.000Z')
+
+                   For a description of IAM and its features, see the
+                   [IAM developer's
+                   guide](\ https://cloud.google.com/iam/docs).
 
         """
         # Create or coerce a protobuf request object.
@@ -1422,7 +1420,7 @@ class SecretManagerServiceAsyncClient:
         warning.
 
         Args:
-            request (:class:`~.iam_policy.TestIamPermissionsRequest`):
+            request (:class:`google.iam.v1.iam_policy_pb2.TestIamPermissionsRequest`):
                 The request object. Request message for
                 `TestIamPermissions` method.
 
@@ -1433,8 +1431,8 @@ class SecretManagerServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.iam_policy.TestIamPermissionsResponse:
-                Response message for ``TestIamPermissions`` method.
+            google.iam.v1.iam_policy_pb2.TestIamPermissionsResponse:
+                Response message for TestIamPermissions method.
         """
         # Create or coerce a protobuf request object.
 
