@@ -124,6 +124,22 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         DEFAULT_ENDPOINT
     )
 
+    @classmethod
+    def from_service_account_info(cls, info: dict, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials info.
+
+        Args:
+            info (dict): The service account private key info.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            SecretManagerServiceClient: The constructed client.
+        """
+        credentials = service_account.Credentials.from_service_account_info(info)
+        kwargs["credentials"] = credentials
+        return cls(*args, **kwargs)
+
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
@@ -136,7 +152,7 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
             kwargs: Additional arguments to pass to the constructor.
 
         Returns:
-            {@api.name}: The constructed client.
+            SecretManagerServiceClient: The constructed client.
         """
         credentials = service_account.Credentials.from_service_account_file(filename)
         kwargs["credentials"] = credentials
@@ -257,10 +273,10 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
                 credentials identify the application to the service; if none
                 are specified, the client will attempt to ascertain the
                 credentials from the environment.
-            transport (Union[str, ~.SecretManagerServiceTransport]): The
+            transport (Union[str, SecretManagerServiceTransport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
-            client_options (client_options_lib.ClientOptions): Custom options for the
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -370,13 +386,14 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         r"""Lists [Secrets][google.cloud.secrets.v1beta1.Secret].
 
         Args:
-            request (:class:`~.service.ListSecretsRequest`):
+            request (google.cloud.secretmanager_v1beta1.types.ListSecretsRequest):
                 The request object. Request message for
                 [SecretManagerService.ListSecrets][google.cloud.secrets.v1beta1.SecretManagerService.ListSecrets].
-            parent (:class:`str`):
+            parent (str):
                 Required. The resource name of the project associated
                 with the [Secrets][google.cloud.secrets.v1beta1.Secret],
                 in the format ``projects/*``.
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -388,7 +405,7 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.pagers.ListSecretsPager:
+            google.cloud.secretmanager_v1beta1.services.secret_manager_service.pagers.ListSecretsPager:
                 Response message for
                 [SecretManagerService.ListSecrets][google.cloud.secrets.v1beta1.SecretManagerService.ListSecrets].
 
@@ -457,30 +474,33 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         [SecretVersions][google.cloud.secrets.v1beta1.SecretVersion].
 
         Args:
-            request (:class:`~.service.CreateSecretRequest`):
+            request (google.cloud.secretmanager_v1beta1.types.CreateSecretRequest):
                 The request object. Request message for
                 [SecretManagerService.CreateSecret][google.cloud.secrets.v1beta1.SecretManagerService.CreateSecret].
-            parent (:class:`str`):
+            parent (str):
                 Required. The resource name of the project to associate
                 with the [Secret][google.cloud.secrets.v1beta1.Secret],
                 in the format ``projects/*``.
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            secret_id (:class:`str`):
+            secret_id (str):
                 Required. This must be unique within the project.
 
                 A secret ID is a string with a maximum length of 255
                 characters and can contain uppercase and lowercase
                 letters, numerals, and the hyphen (``-``) and underscore
                 (``_``) characters.
+
                 This corresponds to the ``secret_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            secret (:class:`~.resources.Secret`):
+            secret (google.cloud.secretmanager_v1beta1.types.Secret):
                 Required. A
                 [Secret][google.cloud.secrets.v1beta1.Secret] with
                 initial field values.
+
                 This corresponds to the ``secret`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -492,14 +512,14 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.resources.Secret:
-                A [Secret][google.cloud.secrets.v1beta1.Secret] is a
-                logical secret whose value and versions can be accessed.
+            google.cloud.secretmanager_v1beta1.types.Secret:
+                A [Secret][google.cloud.secrets.v1beta1.Secret] is a logical secret whose value and versions can
+                   be accessed.
 
-                A [Secret][google.cloud.secrets.v1beta1.Secret] is made
-                up of zero or more
-                [SecretVersions][google.cloud.secrets.v1beta1.SecretVersion]
-                that represent the secret data.
+                   A [Secret][google.cloud.secrets.v1beta1.Secret] is
+                   made up of zero or more
+                   [SecretVersions][google.cloud.secrets.v1beta1.SecretVersion]
+                   that represent the secret data.
 
         """
         # Create or coerce a protobuf request object.
@@ -561,21 +581,23 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         [Secret][google.cloud.secrets.v1beta1.Secret].
 
         Args:
-            request (:class:`~.service.AddSecretVersionRequest`):
+            request (google.cloud.secretmanager_v1beta1.types.AddSecretVersionRequest):
                 The request object. Request message for
                 [SecretManagerService.AddSecretVersion][google.cloud.secrets.v1beta1.SecretManagerService.AddSecretVersion].
-            parent (:class:`str`):
+            parent (str):
                 Required. The resource name of the
                 [Secret][google.cloud.secrets.v1beta1.Secret] to
                 associate with the
                 [SecretVersion][google.cloud.secrets.v1beta1.SecretVersion]
                 in the format ``projects/*/secrets/*``.
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            payload (:class:`~.resources.SecretPayload`):
+            payload (google.cloud.secretmanager_v1beta1.types.SecretPayload):
                 Required. The secret payload of the
                 [SecretVersion][google.cloud.secrets.v1beta1.SecretVersion].
+
                 This corresponds to the ``payload`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -587,7 +609,7 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.resources.SecretVersion:
+            google.cloud.secretmanager_v1beta1.types.SecretVersion:
                 A secret version resource in the
                 Secret Manager API.
 
@@ -646,13 +668,14 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         [Secret][google.cloud.secrets.v1beta1.Secret].
 
         Args:
-            request (:class:`~.service.GetSecretRequest`):
+            request (google.cloud.secretmanager_v1beta1.types.GetSecretRequest):
                 The request object. Request message for
                 [SecretManagerService.GetSecret][google.cloud.secrets.v1beta1.SecretManagerService.GetSecret].
-            name (:class:`str`):
+            name (str):
                 Required. The resource name of the
                 [Secret][google.cloud.secrets.v1beta1.Secret], in the
                 format ``projects/*/secrets/*``.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -664,14 +687,14 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.resources.Secret:
-                A [Secret][google.cloud.secrets.v1beta1.Secret] is a
-                logical secret whose value and versions can be accessed.
+            google.cloud.secretmanager_v1beta1.types.Secret:
+                A [Secret][google.cloud.secrets.v1beta1.Secret] is a logical secret whose value and versions can
+                   be accessed.
 
-                A [Secret][google.cloud.secrets.v1beta1.Secret] is made
-                up of zero or more
-                [SecretVersions][google.cloud.secrets.v1beta1.SecretVersion]
-                that represent the secret data.
+                   A [Secret][google.cloud.secrets.v1beta1.Secret] is
+                   made up of zero or more
+                   [SecretVersions][google.cloud.secrets.v1beta1.SecretVersion]
+                   that represent the secret data.
 
         """
         # Create or coerce a protobuf request object.
@@ -727,18 +750,20 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         [Secret][google.cloud.secrets.v1beta1.Secret].
 
         Args:
-            request (:class:`~.service.UpdateSecretRequest`):
+            request (google.cloud.secretmanager_v1beta1.types.UpdateSecretRequest):
                 The request object. Request message for
                 [SecretManagerService.UpdateSecret][google.cloud.secrets.v1beta1.SecretManagerService.UpdateSecret].
-            secret (:class:`~.resources.Secret`):
+            secret (google.cloud.secretmanager_v1beta1.types.Secret):
                 Required. [Secret][google.cloud.secrets.v1beta1.Secret]
                 with updated field values.
+
                 This corresponds to the ``secret`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            update_mask (:class:`~.field_mask.FieldMask`):
+            update_mask (google.protobuf.field_mask_pb2.FieldMask):
                 Required. Specifies the fields to be
                 updated.
+
                 This corresponds to the ``update_mask`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -750,14 +775,14 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.resources.Secret:
-                A [Secret][google.cloud.secrets.v1beta1.Secret] is a
-                logical secret whose value and versions can be accessed.
+            google.cloud.secretmanager_v1beta1.types.Secret:
+                A [Secret][google.cloud.secrets.v1beta1.Secret] is a logical secret whose value and versions can
+                   be accessed.
 
-                A [Secret][google.cloud.secrets.v1beta1.Secret] is made
-                up of zero or more
-                [SecretVersions][google.cloud.secrets.v1beta1.SecretVersion]
-                that represent the secret data.
+                   A [Secret][google.cloud.secrets.v1beta1.Secret] is
+                   made up of zero or more
+                   [SecretVersions][google.cloud.secrets.v1beta1.SecretVersion]
+                   that represent the secret data.
 
         """
         # Create or coerce a protobuf request object.
@@ -815,13 +840,14 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         r"""Deletes a [Secret][google.cloud.secrets.v1beta1.Secret].
 
         Args:
-            request (:class:`~.service.DeleteSecretRequest`):
+            request (google.cloud.secretmanager_v1beta1.types.DeleteSecretRequest):
                 The request object. Request message for
                 [SecretManagerService.DeleteSecret][google.cloud.secrets.v1beta1.SecretManagerService.DeleteSecret].
-            name (:class:`str`):
+            name (str):
                 Required. The resource name of the
                 [Secret][google.cloud.secrets.v1beta1.Secret] to delete
                 in the format ``projects/*/secrets/*``.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -884,15 +910,16 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         This call does not return secret data.
 
         Args:
-            request (:class:`~.service.ListSecretVersionsRequest`):
+            request (google.cloud.secretmanager_v1beta1.types.ListSecretVersionsRequest):
                 The request object. Request message for
                 [SecretManagerService.ListSecretVersions][google.cloud.secrets.v1beta1.SecretManagerService.ListSecretVersions].
-            parent (:class:`str`):
+            parent (str):
                 Required. The resource name of the
                 [Secret][google.cloud.secrets.v1beta1.Secret] associated
                 with the
                 [SecretVersions][google.cloud.secrets.v1beta1.SecretVersion]
                 to list, in the format ``projects/*/secrets/*``.
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -904,7 +931,7 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.pagers.ListSecretVersionsPager:
+            google.cloud.secretmanager_v1beta1.services.secret_manager_service.pagers.ListSecretVersionsPager:
                 Response message for
                 [SecretManagerService.ListSecretVersions][google.cloud.secrets.v1beta1.SecretManagerService.ListSecretVersions].
 
@@ -974,16 +1001,17 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         [SecretVersion][google.cloud.secrets.v1beta1.SecretVersion].
 
         Args:
-            request (:class:`~.service.GetSecretVersionRequest`):
+            request (google.cloud.secretmanager_v1beta1.types.GetSecretVersionRequest):
                 The request object. Request message for
                 [SecretManagerService.GetSecretVersion][google.cloud.secrets.v1beta1.SecretManagerService.GetSecretVersion].
-            name (:class:`str`):
+            name (str):
                 Required. The resource name of the
                 [SecretVersion][google.cloud.secrets.v1beta1.SecretVersion]
                 in the format ``projects/*/secrets/*/versions/*``.
                 ``projects/*/secrets/*/versions/latest`` is an alias to
                 the ``latest``
                 [SecretVersion][google.cloud.secrets.v1beta1.SecretVersion].
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -995,7 +1023,7 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.resources.SecretVersion:
+            google.cloud.secretmanager_v1beta1.types.SecretVersion:
                 A secret version resource in the
                 Secret Manager API.
 
@@ -1057,13 +1085,14 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         [SecretVersion][google.cloud.secrets.v1beta1.SecretVersion].
 
         Args:
-            request (:class:`~.service.AccessSecretVersionRequest`):
+            request (google.cloud.secretmanager_v1beta1.types.AccessSecretVersionRequest):
                 The request object. Request message for
                 [SecretManagerService.AccessSecretVersion][google.cloud.secrets.v1beta1.SecretManagerService.AccessSecretVersion].
-            name (:class:`str`):
+            name (str):
                 Required. The resource name of the
                 [SecretVersion][google.cloud.secrets.v1beta1.SecretVersion]
                 in the format ``projects/*/secrets/*/versions/*``.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -1075,7 +1104,7 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.service.AccessSecretVersionResponse:
+            google.cloud.secretmanager_v1beta1.types.AccessSecretVersionResponse:
                 Response message for
                 [SecretManagerService.AccessSecretVersion][google.cloud.secrets.v1beta1.SecretManagerService.AccessSecretVersion].
 
@@ -1137,14 +1166,15 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         [DISABLED][google.cloud.secrets.v1beta1.SecretVersion.State.DISABLED].
 
         Args:
-            request (:class:`~.service.DisableSecretVersionRequest`):
+            request (google.cloud.secretmanager_v1beta1.types.DisableSecretVersionRequest):
                 The request object. Request message for
                 [SecretManagerService.DisableSecretVersion][google.cloud.secrets.v1beta1.SecretManagerService.DisableSecretVersion].
-            name (:class:`str`):
+            name (str):
                 Required. The resource name of the
                 [SecretVersion][google.cloud.secrets.v1beta1.SecretVersion]
                 to disable in the format
                 ``projects/*/secrets/*/versions/*``.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -1156,7 +1186,7 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.resources.SecretVersion:
+            google.cloud.secretmanager_v1beta1.types.SecretVersion:
                 A secret version resource in the
                 Secret Manager API.
 
@@ -1218,14 +1248,15 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         [ENABLED][google.cloud.secrets.v1beta1.SecretVersion.State.ENABLED].
 
         Args:
-            request (:class:`~.service.EnableSecretVersionRequest`):
+            request (google.cloud.secretmanager_v1beta1.types.EnableSecretVersionRequest):
                 The request object. Request message for
                 [SecretManagerService.EnableSecretVersion][google.cloud.secrets.v1beta1.SecretManagerService.EnableSecretVersion].
-            name (:class:`str`):
+            name (str):
                 Required. The resource name of the
                 [SecretVersion][google.cloud.secrets.v1beta1.SecretVersion]
                 to enable in the format
                 ``projects/*/secrets/*/versions/*``.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -1237,7 +1268,7 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.resources.SecretVersion:
+            google.cloud.secretmanager_v1beta1.types.SecretVersion:
                 A secret version resource in the
                 Secret Manager API.
 
@@ -1300,14 +1331,15 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         and irrevocably destroys the secret data.
 
         Args:
-            request (:class:`~.service.DestroySecretVersionRequest`):
+            request (google.cloud.secretmanager_v1beta1.types.DestroySecretVersionRequest):
                 The request object. Request message for
                 [SecretManagerService.DestroySecretVersion][google.cloud.secrets.v1beta1.SecretManagerService.DestroySecretVersion].
-            name (:class:`str`):
+            name (str):
                 Required. The resource name of the
                 [SecretVersion][google.cloud.secrets.v1beta1.SecretVersion]
                 to destroy in the format
                 ``projects/*/secrets/*/versions/*``.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -1319,7 +1351,7 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.resources.SecretVersion:
+            google.cloud.secretmanager_v1beta1.types.SecretVersion:
                 A secret version resource in the
                 Secret Manager API.
 
@@ -1380,7 +1412,7 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         [Secret][google.cloud.secrets.v1beta1.Secret].
 
         Args:
-            request (:class:`~.iam_policy.SetIamPolicyRequest`):
+            request (google.iam.v1.iam_policy_pb2.SetIamPolicyRequest):
                 The request object. Request message for `SetIamPolicy`
                 method.
 
@@ -1391,72 +1423,62 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.policy.Policy:
-                Defines an Identity and Access Management (IAM) policy.
-                It is used to specify access control policies for Cloud
-                Platform resources.
+            google.iam.v1.policy_pb2.Policy:
+                Defines an Identity and Access Management (IAM) policy. It is used to
+                   specify access control policies for Cloud Platform
+                   resources.
 
-                A ``Policy`` is a collection of ``bindings``. A
-                ``binding`` binds one or more ``members`` to a single
-                ``role``. Members can be user accounts, service
-                accounts, Google groups, and domains (such as G Suite).
-                A ``role`` is a named list of permissions (defined by
-                IAM or configured by users). A ``binding`` can
-                optionally specify a ``condition``, which is a logic
-                expression that further constrains the role binding
-                based on attributes about the request and/or target
-                resource.
+                   A Policy is a collection of bindings. A binding binds
+                   one or more members to a single role. Members can be
+                   user accounts, service accounts, Google groups, and
+                   domains (such as G Suite). A role is a named list of
+                   permissions (defined by IAM or configured by users).
+                   A binding can optionally specify a condition, which
+                   is a logic expression that further constrains the
+                   role binding based on attributes about the request
+                   and/or target resource.
 
-                **JSON Example**
+                   **JSON Example**
 
-                ::
+                      {
+                         "bindings": [
+                            {
+                               "role":
+                               "roles/resourcemanager.organizationAdmin",
+                               "members": [ "user:mike@example.com",
+                               "group:admins@example.com",
+                               "domain:google.com",
+                               "serviceAccount:my-project-id@appspot.gserviceaccount.com"
+                               ]
 
-                    {
-                      "bindings": [
-                        {
-                          "role": "roles/resourcemanager.organizationAdmin",
-                          "members": [
-                            "user:mike@example.com",
-                            "group:admins@example.com",
-                            "domain:google.com",
-                            "serviceAccount:my-project-id@appspot.gserviceaccount.com"
-                          ]
-                        },
-                        {
-                          "role": "roles/resourcemanager.organizationViewer",
-                          "members": ["user:eve@example.com"],
-                          "condition": {
-                            "title": "expirable access",
-                            "description": "Does not grant access after Sep 2020",
-                            "expression": "request.time <
-                            timestamp('2020-10-01T00:00:00.000Z')",
-                          }
-                        }
-                      ]
-                    }
+                            }, { "role":
+                            "roles/resourcemanager.organizationViewer",
+                            "members": ["user:eve@example.com"],
+                            "condition": { "title": "expirable access",
+                            "description": "Does not grant access after
+                            Sep 2020", "expression": "request.time <
+                            timestamp('2020-10-01T00:00:00.000Z')", } }
 
-                **YAML Example**
+                         ]
 
-                ::
+                      }
 
-                    bindings:
-                    - members:
-                      - user:mike@example.com
-                      - group:admins@example.com
-                      - domain:google.com
-                      - serviceAccount:my-project-id@appspot.gserviceaccount.com
-                      role: roles/resourcemanager.organizationAdmin
-                    - members:
-                      - user:eve@example.com
-                      role: roles/resourcemanager.organizationViewer
-                      condition:
-                        title: expirable access
-                        description: Does not grant access after Sep 2020
-                        expression: request.time < timestamp('2020-10-01T00:00:00.000Z')
+                   **YAML Example**
 
-                For a description of IAM and its features, see the `IAM
-                developer's
-                guide <https://cloud.google.com/iam/docs>`__.
+                      bindings: - members: - user:\ mike@example.com -
+                      group:\ admins@example.com - domain:google.com -
+                      serviceAccount:\ my-project-id@appspot.gserviceaccount.com
+                      role: roles/resourcemanager.organizationAdmin -
+                      members: - user:\ eve@example.com role:
+                      roles/resourcemanager.organizationViewer
+                      condition: title: expirable access description:
+                      Does not grant access after Sep 2020 expression:
+                      request.time <
+                      timestamp('2020-10-01T00:00:00.000Z')
+
+                   For a description of IAM and its features, see the
+                   [IAM developer's
+                   guide](\ https://cloud.google.com/iam/docs).
 
         """
         # Create or coerce a protobuf request object.
@@ -1495,7 +1517,7 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         have a policy set.
 
         Args:
-            request (:class:`~.iam_policy.GetIamPolicyRequest`):
+            request (google.iam.v1.iam_policy_pb2.GetIamPolicyRequest):
                 The request object. Request message for `GetIamPolicy`
                 method.
 
@@ -1506,72 +1528,62 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.policy.Policy:
-                Defines an Identity and Access Management (IAM) policy.
-                It is used to specify access control policies for Cloud
-                Platform resources.
+            google.iam.v1.policy_pb2.Policy:
+                Defines an Identity and Access Management (IAM) policy. It is used to
+                   specify access control policies for Cloud Platform
+                   resources.
 
-                A ``Policy`` is a collection of ``bindings``. A
-                ``binding`` binds one or more ``members`` to a single
-                ``role``. Members can be user accounts, service
-                accounts, Google groups, and domains (such as G Suite).
-                A ``role`` is a named list of permissions (defined by
-                IAM or configured by users). A ``binding`` can
-                optionally specify a ``condition``, which is a logic
-                expression that further constrains the role binding
-                based on attributes about the request and/or target
-                resource.
+                   A Policy is a collection of bindings. A binding binds
+                   one or more members to a single role. Members can be
+                   user accounts, service accounts, Google groups, and
+                   domains (such as G Suite). A role is a named list of
+                   permissions (defined by IAM or configured by users).
+                   A binding can optionally specify a condition, which
+                   is a logic expression that further constrains the
+                   role binding based on attributes about the request
+                   and/or target resource.
 
-                **JSON Example**
+                   **JSON Example**
 
-                ::
+                      {
+                         "bindings": [
+                            {
+                               "role":
+                               "roles/resourcemanager.organizationAdmin",
+                               "members": [ "user:mike@example.com",
+                               "group:admins@example.com",
+                               "domain:google.com",
+                               "serviceAccount:my-project-id@appspot.gserviceaccount.com"
+                               ]
 
-                    {
-                      "bindings": [
-                        {
-                          "role": "roles/resourcemanager.organizationAdmin",
-                          "members": [
-                            "user:mike@example.com",
-                            "group:admins@example.com",
-                            "domain:google.com",
-                            "serviceAccount:my-project-id@appspot.gserviceaccount.com"
-                          ]
-                        },
-                        {
-                          "role": "roles/resourcemanager.organizationViewer",
-                          "members": ["user:eve@example.com"],
-                          "condition": {
-                            "title": "expirable access",
-                            "description": "Does not grant access after Sep 2020",
-                            "expression": "request.time <
-                            timestamp('2020-10-01T00:00:00.000Z')",
-                          }
-                        }
-                      ]
-                    }
+                            }, { "role":
+                            "roles/resourcemanager.organizationViewer",
+                            "members": ["user:eve@example.com"],
+                            "condition": { "title": "expirable access",
+                            "description": "Does not grant access after
+                            Sep 2020", "expression": "request.time <
+                            timestamp('2020-10-01T00:00:00.000Z')", } }
 
-                **YAML Example**
+                         ]
 
-                ::
+                      }
 
-                    bindings:
-                    - members:
-                      - user:mike@example.com
-                      - group:admins@example.com
-                      - domain:google.com
-                      - serviceAccount:my-project-id@appspot.gserviceaccount.com
-                      role: roles/resourcemanager.organizationAdmin
-                    - members:
-                      - user:eve@example.com
-                      role: roles/resourcemanager.organizationViewer
-                      condition:
-                        title: expirable access
-                        description: Does not grant access after Sep 2020
-                        expression: request.time < timestamp('2020-10-01T00:00:00.000Z')
+                   **YAML Example**
 
-                For a description of IAM and its features, see the `IAM
-                developer's
-                guide <https://cloud.google.com/iam/docs>`__.
+                      bindings: - members: - user:\ mike@example.com -
+                      group:\ admins@example.com - domain:google.com -
+                      serviceAccount:\ my-project-id@appspot.gserviceaccount.com
+                      role: roles/resourcemanager.organizationAdmin -
+                      members: - user:\ eve@example.com role:
+                      roles/resourcemanager.organizationViewer
+                      condition: title: expirable access description:
+                      Does not grant access after Sep 2020 expression:
+                      request.time <
+                      timestamp('2020-10-01T00:00:00.000Z')
+
+                   For a description of IAM and its features, see the
+                   [IAM developer's
+                   guide](\ https://cloud.google.com/iam/docs).
 
         """
         # Create or coerce a protobuf request object.
@@ -1615,7 +1627,7 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         warning.
 
         Args:
-            request (:class:`~.iam_policy.TestIamPermissionsRequest`):
+            request (google.iam.v1.iam_policy_pb2.TestIamPermissionsRequest):
                 The request object. Request message for
                 `TestIamPermissions` method.
 
@@ -1626,8 +1638,8 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.iam_policy.TestIamPermissionsResponse:
-                Response message for ``TestIamPermissions`` method.
+            google.iam.v1.iam_policy_pb2.TestIamPermissionsResponse:
+                Response message for TestIamPermissions method.
         """
         # Create or coerce a protobuf request object.
 
